@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2007-2010 Pedro Castro
+ * Copyright (C) 2007-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,15 +42,22 @@ public class Config {
 	private const string keyPrefsEncodings = keyPrefs + "encodings/";
 	private const string keyPrefsSpellCheck = keyPrefs + "spellcheck/";
 	private const string keyPrefsVideo = keyPrefs + "video/";
+	private const string keyPrefsView = keyPrefs + "view/";
 	private const string keyPrefsWindow = keyPrefs + "window/";
 	private const string keyPrefsDefaults = keyPrefs + "defaults/";
 	private const string keyPrefsTranslation = keyPrefs + "translation/";
 	private const string keyPrefsBackup = keyPrefs + "backup/";
+	private const string keyPrefsTimings = keyPrefs + "timings/";
 
 	/* Constant key strings */
 	private const string keyPrefsEncodingsShownInMenu = keyPrefsEncodings + "shown_in_menu";
 	private const string keyPrefsTranslationSaveAll = keyPrefsTranslation + "save_all";
 	private const string keyPrefsVideoAutoChooseFile = keyPrefsVideo + "auto_choose_file";
+	private const string keyPrefsVideoApplyReactionDelay = keyPrefsVideo + "apply_reaction_delay";
+	private const string keyPrefsVideoReactionDelay = keyPrefsVideo + "reaction_delay";
+	private const string keyPrefsVideoSeekOnChange = keyPrefsVideo + "seek_on_change";
+	private const string keyPrefsVideoSeekOnChangeRewind = keyPrefsVideo + "seek_on_change_rewind";
+	private const string keyPrefsViewLineLengths = keyPrefsView + "line_lengths";
 	private const string keyPrefsSpellCheckActiveTextLanguage = keyPrefsSpellCheck + "active_text_language";
 	private const string keyPrefsSpellCheckActiveTranslationLanguage = keyPrefsSpellCheck + "active_translation_language";
 	private const string keyPrefsSpellCheckAutocheck = keyPrefsSpellCheck + "autocheck";
@@ -67,7 +74,23 @@ public class Config {
 	private const string keyPrefsDefaultsFileSaveNewline = keyPrefsDefaults + "file_save_newline";
 	private const string keyPrefsBackupAutoBackup = keyPrefsBackup + "auto_backup";
 	private const string keyPrefsBackupBackupTime = keyPrefsBackup + "backup_time";
-
+	private const string keyPrefsTimingsTimeStep = keyPrefsTimings + "time_step"; //Not editable in the Preferences dialog
+	private const string keyPrefsTimingsFramesStep = keyPrefsTimings + "frames_step"; //Not editable in the Preferences dialog
+	private const string keyPrefsTimingsTimeBetweenSubtitles = keyPrefsTimings + "time_between_subs";
+	
+	/* Cached values */
+	private bool isValuePrefsViewLineLengthsCached = false;
+	private bool valuePrefsViewLineLengths = false;
+	private bool isValuePrefsVideoApplyReactionDelayCached = false;
+	private bool valuePrefsVideoApplyReactionDelay = false;
+	private int valuePrefsVideoReactionDelay = -1;
+	private bool isValuePrefsVideoSeekOnChangeCached = false;
+	private bool valuePrefsVideoSeekOnChange = false;
+	private int valuePrefsVideoSeekOnChangeRewind = -1;
+	private int valuePrefsTimingsTimeStep = -1;
+	private int valuePrefsTimingsFramesStep = -1;
+	private int valuePrefsTimingsTimeBetweenSubtitles = -1;
+	
 
 	public Config () {
 		client = new Client();
@@ -103,6 +126,77 @@ public class Config {
 		set { Set(keyPrefsVideoAutoChooseFile, value); }
 	}
 	
+	public bool PrefsVideoApplyReactionDelay {
+		get {
+			if (!isValuePrefsVideoApplyReactionDelayCached) {
+				this.valuePrefsVideoApplyReactionDelay = GetBool(keyPrefsVideoApplyReactionDelay, false);
+				this.isValuePrefsVideoApplyReactionDelayCached = true;
+			}
+			return valuePrefsVideoApplyReactionDelay;
+		}
+		set {
+			Set(keyPrefsVideoApplyReactionDelay, value);
+			this.valuePrefsVideoApplyReactionDelay = value;
+			this.isValuePrefsVideoApplyReactionDelayCached = true;
+		}
+	}
+
+	public int PrefsVideoReactionDelay {
+		get {
+			if (this.valuePrefsVideoReactionDelay == -1) {
+				this.valuePrefsVideoReactionDelay = GetInt(keyPrefsVideoReactionDelay, 200, 0, true, 2000, true);
+			}
+			return this.valuePrefsVideoReactionDelay;
+		}
+		set {
+			Set(keyPrefsVideoReactionDelay, value);
+			this.valuePrefsVideoReactionDelay = value;
+		}
+	}
+	
+	public bool PrefsVideoSeekOnChange {
+		get {
+			if (!isValuePrefsVideoSeekOnChangeCached) {
+				this.valuePrefsVideoSeekOnChange = GetBool(keyPrefsVideoSeekOnChange, true);
+				this.isValuePrefsVideoSeekOnChangeCached = true;
+			}
+			return valuePrefsVideoSeekOnChange;
+		}
+		set {
+			Set(keyPrefsVideoSeekOnChange, value);
+			this.valuePrefsVideoSeekOnChange = value;
+			this.isValuePrefsVideoSeekOnChangeCached = true;
+		}
+	}
+
+	public int PrefsVideoSeekOnChangeRewind {
+		get {
+			if (this.valuePrefsVideoSeekOnChangeRewind == -1) {
+				this.valuePrefsVideoSeekOnChangeRewind = GetInt(keyPrefsVideoSeekOnChangeRewind, 200, 0, true, 2000, true);
+			}
+			return this.valuePrefsVideoSeekOnChangeRewind;
+		}
+		set {
+			Set(keyPrefsVideoSeekOnChangeRewind, value);
+			this.valuePrefsVideoSeekOnChangeRewind = value;
+		}
+	}
+	
+	public bool PrefsViewLineLengths {
+		get {
+			if (!isValuePrefsViewLineLengthsCached) {
+				this.valuePrefsViewLineLengths = GetBool(keyPrefsViewLineLengths, true);
+				this.isValuePrefsViewLineLengthsCached = true;
+			}
+			return valuePrefsViewLineLengths;
+		}
+		set {
+			Set(keyPrefsViewLineLengths, value);
+			this.valuePrefsViewLineLengths = value;
+			this.isValuePrefsViewLineLengthsCached = true;
+		}
+	}
+
 	public int PrefsWindowHeight {
 		get { return GetInt(keyPrefsWindowHeight, 600, 200, true, 0, false); }
 		set { Set(keyPrefsWindowHeight, value); }
@@ -193,11 +287,50 @@ public class Config {
 		set { Set(keyPrefsBackupAutoBackup, value); }
 	}
  
-	/* Backup time in seconds */
 	public int PrefsBackupBackupTime {
 		get { return GetInt(keyPrefsBackupBackupTime, 120, 30, true, 0, false); }
 		set { Set(keyPrefsBackupBackupTime, value); }
 	}
+	
+	/* Time in milliseconds */
+	public int PrefsTimingsTimeStep {
+		get {
+			if (this.valuePrefsTimingsTimeStep == -1) {
+				this.valuePrefsTimingsTimeStep = GetInt(keyPrefsTimingsTimeStep, 100, 1, true, 2000, true);
+			}
+			return this.valuePrefsTimingsTimeStep;
+		}
+		set {
+			Set(keyPrefsTimingsTimeStep, value);
+			this.valuePrefsTimingsTimeStep = value;
+		}
+	}
+	
+	public int PrefsTimingsFramesStep {
+		get {
+			if (this.valuePrefsTimingsFramesStep == -1) {
+				this.valuePrefsTimingsFramesStep = GetInt(keyPrefsTimingsFramesStep, 2, 1, true, 60, true);
+			}
+			return this.valuePrefsTimingsFramesStep;
+		}
+		set {
+			Set(keyPrefsTimingsFramesStep, value);
+			this.valuePrefsTimingsFramesStep = value;
+		}
+	}
+	
+	public int PrefsTimingsTimeBetweenSubtitles {
+		get {
+			if (this.valuePrefsTimingsTimeBetweenSubtitles == -1) {
+				this.valuePrefsTimingsTimeBetweenSubtitles = GetInt(keyPrefsTimingsTimeBetweenSubtitles, 100, 0, true, 2000, true);
+			}
+			return this.valuePrefsTimingsTimeBetweenSubtitles;
+		}
+		set {
+			Set(keyPrefsTimingsTimeBetweenSubtitles, value);
+			this.valuePrefsTimingsTimeBetweenSubtitles = value;
+		}
+	}
 
 	
 	/* Private members */
@@ -221,15 +354,6 @@ public class Config {
 			return defaultValue;
 		}
 	}
-
-	/* private int GetInt (string key, int defaultValue) {
-		try {
-			return (int)client.Get(key);
-		}
-		catch (Exception) {
-			return defaultValue;
-		}
-	}*/
 	
 	private int GetInt (string key, int defaultValue, int lowerLimit, bool useLowerLimit, int upperLimit, bool useUpperLimit) {
 		try {
