@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2010 Pedro Castro
+ * Copyright (C) 2006-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ using System;
 namespace GnomeSubtitles.Dialog {
 
 //TODO set spinButton limits according to selection type
+//TODO show informative message about the Ctrl+Shift++ shortcuts
 public class TimingsShiftDialog : GladeDialog {
 	private TimingMode timingMode = TimingMode.Frames;
 
@@ -65,7 +66,7 @@ public class TimingsShiftDialog : GladeDialog {
 	}
 	
 	private void InitSpinButton () {
-		spinButton.WidthRequest = Core.Util.SpinButtonTimeWidth(spinButton);
+		spinButton.WidthChars = Core.Util.SpinButtonTimeWidthChars;
 		spinButton.Alignment = 0.5f;
 	}
 
