@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2009 Pedro Castro
+ * Copyright (C) 2006-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@ namespace GnomeSubtitles.Dialog {
 
 public class VideoOpenDialog : GladeDialog {
 	protected FileChooserDialog dialog = null;
-	private static string[] extensions = { "avi", "mpeg", "mpg", "mp4", "ogm", "divx", "xvid", "mov", "ogg", "mkv" };
 	private Uri chosenUri = null;
 	
 	/* Constant strings */
@@ -52,22 +51,29 @@ public class VideoOpenDialog : GladeDialog {
 	
 	/* Private methods */
 
-	/* TODO check how other players are setting up the filters, possibly using MIME types. */
 	private void SetFilters () {
 
-		/* First filter corresponds to all files */
+		/* Video files */
+		FileFilter videoFilesFilter = new FileFilter();
+		videoFilesFilter.Name = Catalog.GetString("All Video Files");
+		videoFilesFilter.AddMimeType("video/*");
+		videoFilesFilter.AddMimeType("application/vnd.rn-realmedia"); //support for real media files (currently includes rmvb)
+		videoFilesFilter.AddMimeType("application/vnd.rn-realmedia-vbr"); //this should be the real mime type for rmvb files
+		dialog.AddFilter(videoFilesFilter);
+		
+		/* Audio files */
+		FileFilter audioFilesFilter = new FileFilter();
+		audioFilesFilter.Name = Catalog.GetString("All Audio Files");
+		audioFilesFilter.AddMimeType("audio/*");
+		audioFilesFilter.AddMimeType("application/ogg");
+		dialog.AddFilter(audioFilesFilter);
+
+		
+		/* All files */
 		FileFilter allFilesFilter = new FileFilter();
 		allFilesFilter.Name = Catalog.GetString("All Files");
 		allFilesFilter.AddPattern("*");
-		dialog.AddFilter(allFilesFilter);
-		
-		/* Second filter corresponds to video files */
-		FileFilter videoFilesFilter = new FileFilter();
-		videoFilesFilter.Name = Catalog.GetString("All Video Files");
-		foreach (string extension in extensions) {
-			videoFilesFilter.AddPattern("*." + extension);
-		}
-		dialog.AddFilter(videoFilesFilter);
+		dialog.AddFilter(allFilesFilter);		
 		
 		/* Set active filter */
 		dialog.Filter = videoFilesFilter;
