@@ -31,11 +31,35 @@ public class ExecutionContext {
 	/* Constant strings */
 	private const string applicationName = "Gnome Subtitles";
 	private const string applicationID = "gnome-subtitles";
+
+	/* Dynamic variables */
+	private string localeDir = String.Empty;
+	private bool platformIsWindows = false;
+	private bool platformIsUnix = false;
 	
 	private string[] args = null;
 	
 	public ExecutionContext (string[] args) {
 		this.args = args;
+
+		SetDynamicVariables();
+	}
+
+	private void SetDynamicVariables () {
+		this.localeDir = System.AppDomain.CurrentDomain.BaseDirectory + "../../share/locale";
+
+		/* Handle platform */
+		switch (Environment.OSVersion.Platform) {
+			case PlatformID.Win32NT:
+			case PlatformID.Win32S:
+			case PlatformID.Win32Windows:
+			case PlatformID.WinCE:
+				platformIsWindows = true;
+				break;
+			case PlatformID.Unix:
+				platformIsUnix = true;
+				break;
+		}
 	}
 	
 	/* Public properties */
@@ -55,6 +79,11 @@ public class ExecutionContext {
 	public string ExecutableName {
 		get { return applicationID; }
 	}
+
+	//Unix only
+	public string LocaleDir {
+		get { return localeDir; }
+	}
 	
 	public string Version {
 		get { return RemoveTrailingZeros(Assembly.GetExecutingAssembly().GetName().Version.ToString()); }
@@ -80,6 +109,14 @@ public class ExecutionContext {
 	public string TranslationDomain {
 		get { return applicationID; }
 	}
+
+	public bool PlatformIsWindows {
+		get { return platformIsWindows; }
+	}
+
+	public bool PlatformIsUnix {
+		get { return platformIsUnix; }
+	}
 	
 
 	/* Public methods */
