@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2010 Pedro Castro
+ * Copyright (C) 2006-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,9 +35,7 @@ public class SubtitleEditSpinButtons {
 	
 	/* Constants */
 	private const int maxTime = 86399999; //milliseconds
-	private const int timeStepIncrement = 100; //milliseconds
 	private const int maxFrames = 3000000;
-	private const int framesStepIncrement = 1;
 
 
 	public SubtitleEditSpinButtons () {
@@ -47,7 +45,9 @@ public class SubtitleEditSpinButtons {
 		durationSpinButton = Base.GetWidget(WidgetNames.DurationSpinButton) as SpinButton;
 		
 		/* Initialize */
-		startSpinButton.WidthRequest = Util.SpinButtonTimeWidth(startSpinButton); //Only need to set one of the spin buttons' width
+		startSpinButton.WidthChars = Util.SpinButtonTimeWidthChars;
+		endSpinButton.WidthChars = Util.SpinButtonTimeWidthChars;
+		durationSpinButton.WidthChars = Util.SpinButtonTimeWidthChars;
     	
     	/* Set timing mode to Times */
     	SetTimingMode(TimingMode.Times); //Initial timing mode is Times
@@ -72,6 +72,22 @@ public class SubtitleEditSpinButtons {
     	endSpinButton = this.endSpinButton;
     	durationSpinButton = this.durationSpinButton;
     }
+    
+    public void StartSpinButtonIncreaseStep () {
+    	startSpinButton.Spin(SpinType.StepForward, 0); //0 uses the defined stepIncrement
+    }
+
+    public void StartSpinButtonDecreaseStep () {
+    	startSpinButton.Spin(SpinType.StepBackward, 0); //0 uses the defined stepIncrement
+    }
+    
+    public void EndSpinButtonIncreaseStep () {
+    	endSpinButton.Spin(SpinType.StepForward, 0); //0 uses the defined stepIncrement
+    }
+
+    public void EndSpinButtonDecreaseStep () {
+    	endSpinButton.Spin(SpinType.StepBackward, 0); //0 uses the defined stepIncrement
+    }
 
 
 	/* Private methods */
@@ -102,7 +118,7 @@ public class SubtitleEditSpinButtons {
     private void SetTimesMode (SpinButton spinButton, bool allowNegatives) {
 		Util.SetSpinButtonTimingMode(spinButton, TimingMode.Times);
 
-		spinButton.Adjustment.StepIncrement = timeStepIncrement;
+		spinButton.Adjustment.StepIncrement = Base.Config.PrefsTimingsTimeStep;
 		spinButton.Adjustment.Upper = maxTime;
 		spinButton.Adjustment.Lower = (allowNegatives ? -maxTime : 0);
 	}
@@ -111,7 +127,7 @@ public class SubtitleEditSpinButtons {
 	private void SetFramesMode (SpinButton spinButton, bool allowNegatives) {
 		Util.SetSpinButtonTimingMode(spinButton, TimingMode.Frames);
 
-    	spinButton.Adjustment.StepIncrement = framesStepIncrement;
+    	spinButton.Adjustment.StepIncrement = Base.Config.PrefsTimingsFramesStep;
     	spinButton.Adjustment.Upper = maxFrames;
     	spinButton.Adjustment.Lower = (allowNegatives ? -maxFrames : 0);
 	}
@@ -174,23 +190,23 @@ public class SubtitleEditSpinButtons {
    	
 	private void OnStartValueChanged (object o, EventArgs args) {
 		if (Base.TimingModeIsFrames)
-			Base.CommandManager.Execute(new ChangeStartCommand((int)startSpinButton.Value));
+			Base.CommandManager.Execute(new ChangeStartCommand((int)startSpinButton.Value, true));
 		else
-			Base.CommandManager.Execute(new ChangeStartCommand(TimeSpan.FromMilliseconds(startSpinButton.Value)));
+			Base.CommandManager.Execute(new ChangeStartCommand(TimeSpan.FromMilliseconds(startSpinButton.Value), true));
 	}
 	
 	private void OnEndValueChanged (object o, EventArgs args) {
 		if (Base.TimingModeIsFrames)
-			Base.CommandManager.Execute(new ChangeEndCommand((int)endSpinButton.Value));
+			Base.CommandManager.Execute(new ChangeEndCommand((int)endSpinButton.Value, true));
 		else
-			Base.CommandManager.Execute(new ChangeEndCommand(TimeSpan.FromMilliseconds(endSpinButton.Value)));
+			Base.CommandManager.Execute(new ChangeEndCommand(TimeSpan.FromMilliseconds(endSpinButton.Value), true));
 	}
 	
 	private void OnDurationValueChanged (object o, EventArgs args) {
 		if (Base.TimingModeIsFrames)
-			Base.CommandManager.Execute(new ChangeDurationCommand((int)durationSpinButton.Value));
+			Base.CommandManager.Execute(new ChangeDurationCommand((int)durationSpinButton.Value, true));
 		else
-			Base.CommandManager.Execute(new ChangeDurationCommand(TimeSpan.FromMilliseconds(durationSpinButton.Value)));
+			Base.CommandManager.Execute(new ChangeDurationCommand(TimeSpan.FromMilliseconds(durationSpinButton.Value), true));
 	}
 	
 	private void OnBaseInitFinished () {
