@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2010 Pedro Castro
+ * Copyright (C) 2006-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,8 +32,6 @@ public class Menus {
 	/* Constant strings */
 	private string videoTagText = Catalog.GetString("Video");
 
-	/* Public methods */
-
 	public Menus () {
 		SetToolbarHomogeneity(); //TODO needed until homogeneity definition in glade starts working
 		SetDocumentSensitivity(false);
@@ -42,6 +40,24 @@ public class Menus {
 		Base.InitFinished += OnBaseInitFinished;
 	}
 	
+	
+	/* Public properties */
+	
+	public float TimingsInputFrameRateActive {
+		get {
+			Menu menu = Base.GetWidget(WidgetNames.TimingsInputFrameRateMenu) as Menu;
+			foreach (RadioMenuItem menuItem in menu.Children) {
+				if (menuItem.Active) {
+					return FrameRateFromMenuItem((menuItem.Child as Label).Text);
+				}
+			}
+			return -1;
+		}
+	}
+	
+	
+	/* Public methods */
+	
 	public void SetCutCopySensitivity (bool sensitivity) {
 		SetSensitivity(WidgetNames.EditCut, sensitivity);
 		SetSensitivity(WidgetNames.EditCopy, sensitivity);
@@ -54,14 +70,19 @@ public class Menus {
 		SetSensitivity(WidgetNames.PasteButton, sensitivity);
 	}
 	
-	public void UpdateActiveInputFrameRateMenuItem () {
+	public void UpdateActiveInputFrameRateMenuItem (bool toggleHandlers) {
 		float inputFrameRate = Base.Document.Subtitles.Properties.OriginalFrameRate;
-		SetCheckMenuItemActivity(InputFrameRateMenuItem(inputFrameRate), true, Base.Handlers.OnTimingsInputFrameRate);
+		if (toggleHandlers)
+			SetCheckMenuItemActivity(InputFrameRateMenuItem(inputFrameRate), true, OnTimingsInputFrameRateToggled);
+		else
+			SetCheckMenuItemActivity(InputFrameRateMenuItem(inputFrameRate), true);
 	}
 	
+	/* Note: this method makes the assumption that the OnTimingsVideoFrameRateToggled event handler is connected to the
+	   menu item, as it is disconnected and then connected again after changing the active menu item. */
 	public void UpdateActiveVideoFrameRateMenuItem () {
 		float videoFrameRate = Base.Document.Subtitles.Properties.CurrentFrameRate;
-		SetCheckMenuItemActivity(VideoFrameRateMenuItem(videoFrameRate), true, Base.Handlers.OnTimingsVideoFrameRate);
+		SetCheckMenuItemActivity(VideoFrameRateMenuItem(videoFrameRate), true, OnTimingsVideoFrameRateToggled);
 	}
 	
 	public void EnableFindNextPrevious () {
@@ -97,24 +118,22 @@ public class Menus {
 			}
 		}
 	}
-
 	
-	/* Static members */
-	
-	static public float FrameRateFromMenuItem (string menuItem) {
-		string frameRateText = menuItem.Split(' ')[0];
-		NumberFormatInfo invariant = NumberFormatInfo.InvariantInfo;
-		return (float)Convert.ToDouble(frameRateText, invariant);
+	public MenuItem GetMenuItem (string widgetName) {
+		return Base.GetWidget(WidgetNames.ViewLineLengths) as MenuItem;
 	}
 
+	
 	/* Private members */
 	
 	/// <summary>Sets the sensitivity depending on 1 or more selected subtitles.</summary>
+	/// <param name="selectionCount">The number of selected subtitles.</param>
 	/// <param name="sensitivity">Whether the items are set sensitive.</param>
-	private void SetNonZeroSelectionDependentSensitivity (bool sensitivity) {
+	private void SetNonZeroSelectionDependentSensitivity (int selectionCount, bool sensitivity) {
 		SetStylesSensitivity(sensitivity);
 		SetSensitivity(WidgetNames.EditDeleteSubtitles, sensitivity);
-		SetSensitivity(WidgetNames.EditInsertSubtitleBefore, sensitivity);
+		SetSensitivity(WidgetNames.EditSplit, sensitivity);
+		SetSensitivity(WidgetNames.EditMerge, selectionCount >= 2);
 		SetSensitivity(WidgetNames.DeleteSubtitlesButton, sensitivity);
 	}
 	
@@ -122,6 +141,8 @@ public class Menus {
 	/// <param name="sensitivity">Whether the items are set sensitive.</param>
 	private void SetOneSelectionDependentSensitivity (bool sensitivity) {
 		SetVideoSelectionDependentSensitivity(sensitivity);
+		SetSensitivity(WidgetNames.ToolsTranslateText, sensitivity && Base.Document.IsTranslationLoaded);
+		SetSensitivity(WidgetNames.ToolsTranslateTranslation, sensitivity && Base.Document.IsTranslationLoaded);
 	}
 	
 	private void SetSubtitleCountDependentSensitivity (int count) {
@@ -138,9 +159,10 @@ public class Menus {
 			SetSensitivity(WidgetNames.TimingsShift, true);
 		}	
 	}
-	
+
 	private void SetBlankActivity () {
 		SetCheckMenuItemActivity(WidgetNames.ToolsAutocheckSpelling, Base.SpellLanguages.Enabled);
+		SetCheckMenuItemActivity(WidgetNames.ViewLineLengths, Base.Config.PrefsViewLineLengths);
 	}
 	
 	private void SetViewVideoActivity (bool activity) {
@@ -148,8 +170,8 @@ public class Menus {
 	}
 
 	private void SetDocumentSensitivity (bool documentLoaded) {
-		/* Set Sensitivity that is equal to the document loaded status */
-
+		/* Set Sensitivity that corresponds to the document loaded status */
+	
 		/* File Menu */
 		SetSensitivity(WidgetNames.FileSave, documentLoaded);
 		SetSensitivity(WidgetNames.FileSaveAs, documentLoaded);
@@ -174,12 +196,11 @@ public class Menus {
 		/* Tools Menu */
 		SetToolsAutocheckSpellingSensitivity(documentLoaded);
 		SetSensitivity(WidgetNames.ToolsSetTextLanguage, documentLoaded);
-		SetSensitivity(WidgetNames.ToolsSetTranslationLanguage, documentLoaded);
 		/* Toolbar */
 		SetSensitivity(WidgetNames.SaveButton, documentLoaded);
 		SetSensitivity(WidgetNames.InsertSubtitleButton, documentLoaded);
 		
-		/* Set sensitivity that only applies when the document is not loaded */
+		/* Set sensitivity that's only applicable when the document is not loaded */
 		
 		if (!documentLoaded) {
 			/* Edit menu */
@@ -189,10 +210,13 @@ public class Menus {
 			SetSensitivity(WidgetNames.EditCut, false);
 			SetSensitivity(WidgetNames.EditCopy, false);
 			SetSensitivity(WidgetNames.EditPaste, false);
+			SetSensitivity(WidgetNames.EditSplit, false);
+			SetSensitivity(WidgetNames.EditMerge, false);
 			/* Search menu */
 			SetSensitivity(WidgetNames.SearchFindNext, false);
 			SetSensitivity(WidgetNames.SearchFindPrevious, false);
 			/* Timings Menu */
+			SetSensitivity(WidgetNames.TimingsAdjust, false);
 			SetSensitivity(WidgetNames.TimingsShift, false);
 			/* Toolbar */
 			SetSensitivity(WidgetNames.DeleteSubtitlesButton, false);
@@ -211,6 +235,10 @@ public class Menus {
 		SetSensitivity(WidgetNames.FileTranslationSaveAs, sensitivity);
 		SetSensitivity(WidgetNames.FileTranslationClose, sensitivity);
 		SetSensitivity(WidgetNames.ToolsSetTranslationLanguage, sensitivity);
+		
+		bool oneSubtitleSelected = (Core.Base.Ui.View.Selection.Count == 1);
+		SetSensitivity(WidgetNames.ToolsTranslateText, sensitivity && oneSubtitleSelected);
+		SetSensitivity(WidgetNames.ToolsTranslateTranslation, sensitivity && oneSubtitleSelected);
 		SetViewVideoSubtitlesSensitivity();
 	}
 		
@@ -218,18 +246,32 @@ public class Menus {
 		SetSensitivity(WidgetNames.ToolsAutocheckSpelling, sensitivity);
 	}
 	
-	private void SetFrameRateMenus () {
-		if (Base.TimingMode == TimingMode.Frames) {
-			SetMenuSensitivity(WidgetNames.TimingsInputFrameRateMenu, true);
-			SetMenuSensitivity(WidgetNames.TimingsVideoFrameRateMenu, true);
+	private void SetFrameRateMenus (bool documentLoaded) {
+		if (documentLoaded) {
+			if (Base.TimingMode == TimingMode.Frames) {
+				UpdateActiveInputFrameRateMenuItem(false);
+				SetMenuSensitivity(WidgetNames.TimingsInputFrameRateMenu, true);
+				SetFrameRateMenuHandlers(Base.GetWidget(WidgetNames.TimingsInputFrameRateMenu) as Menu, true, OnTimingsInputFrameRateToggled);
+				
+				SetMenuSensitivity(WidgetNames.TimingsVideoFrameRateMenu, true);
+				SetFrameRateMenuHandlers(Base.GetWidget(WidgetNames.TimingsVideoFrameRateMenu) as Menu, true, OnTimingsVideoFrameRateToggled);
+				UpdateActiveVideoFrameRateMenuItem();
+			}
+			else {
+				UpdateActiveInputFrameRateMenuItem(false);
+				SetMenuSensitivity(WidgetNames.TimingsInputFrameRateMenu, false);
+
+				SetMenuSensitivity(WidgetNames.TimingsVideoFrameRateMenu, true);
+				SetFrameRateMenuHandlers(Base.GetWidget(WidgetNames.TimingsVideoFrameRateMenu) as Menu, true, OnTimingsVideoFrameRateToggled);
+				UpdateActiveVideoFrameRateMenuItem();
+			}
 		}
 		else {
-			SetMenuSensitivity(WidgetNames.TimingsInputFrameRateMenu, false);
-			SetMenuSensitivity(WidgetNames.TimingsVideoFrameRateMenu, true);
+			SetFrameRateMenuHandlers(Base.GetWidget(WidgetNames.TimingsInputFrameRateMenu) as Menu, false, OnTimingsInputFrameRateToggled);
+			SetMenuSensitivity(WidgetNames.TimingsInputFrameRateMenu, true);
+			SetFrameRateMenuHandlers(Base.GetWidget(WidgetNames.TimingsVideoFrameRateMenu) as Menu, false, OnTimingsVideoFrameRateToggled);
+			SetMenuSensitivity(WidgetNames.TimingsVideoFrameRateMenu, false);
 		}
-		
-		UpdateActiveInputFrameRateMenuItem();
-		UpdateActiveVideoFrameRateMenuItem();
 	}
 	
 	private void SetStylesActivity (bool bold, bool italic, bool underline) {
@@ -314,6 +356,7 @@ public class Menus {
 		SetSensitivity(WidgetNames.VideoSelectNearestSubtitle, sensitivity);
 		SetSensitivity(WidgetNames.VideoLoopSelectionPlayback, sensitivity);
 		SetSensitivity(WidgetNames.VideoAutoSelectSubtitles, sensitivity);
+		SetSensitivity(WidgetNames.EditInsertSubtitleAtVideoPosition, sensitivity);
 	}
 	
 	private void SetCheckMenuItemActivity (string menuItemName, bool isActive) {
@@ -324,7 +367,7 @@ public class Menus {
 		CheckMenuItem menuItem = Base.GetWidget(menuItemName) as CheckMenuItem;
 		menuItem.Toggled -= handler;
 		menuItem.Active = isActive;
-		menuItem.Toggled += handler;		
+		menuItem.Toggled += handler;
 	}
 	
 	private void SetToggleToolButtonActivity (string toggleToolButtonName, bool isActive, EventHandler handler) {
@@ -450,6 +493,13 @@ public class Menus {
     private void ClearTooltip (Widget widget) {
     	SetTooltip(widget, null);
     }
+    
+   	private float FrameRateFromMenuItem (string menuItem) {
+		string frameRateText = menuItem.Split(' ')[0];
+		NumberFormatInfo invariant = NumberFormatInfo.InvariantInfo;
+		return (float)Convert.ToDouble(frameRateText, invariant);
+	}
+	
 
 	/* Event members */
 	
@@ -471,13 +521,14 @@ public class Menus {
 	
 	private void OnBaseDocumentLoaded (Document document) {
 		SetDocumentSensitivity(true);
-		SetFrameRateMenus();
+		SetFrameRateMenus(true);
 		SetActiveTimingMode(Base.TimingMode);
 		SetCheckMenuItemActivity(WidgetNames.ToolsAutocheckSpelling, Base.SpellLanguages.Enabled);
 	}
 	
 	private void OnBaseDocumentUnloaded (Document document) {
 		SetDocumentSensitivity(false);
+		SetFrameRateMenus(false);
 	}
 	
 	private void OnBaseVideoLoaded (Uri videoUri) {
@@ -514,20 +565,21 @@ public class Menus {
 		if (subtitle != null) {
 			/* One subtitle selected */
 			SetStylesActivity(subtitle.Style.Bold, subtitle.Style.Italic, subtitle.Style.Underline);
-			SetNonZeroSelectionDependentSensitivity(true);
+			SetNonZeroSelectionDependentSensitivity(1, true);
 			SetOneSelectionDependentSensitivity(true);
 		}
 		else {
 			SetOneSelectionDependentSensitivity(false);
+			int selectionCount = paths.Length;
 	
-			if (paths.Length == 0) {
+			if (selectionCount == 0) {
 				/* No selection */
-				SetNonZeroSelectionDependentSensitivity(false);
+				SetNonZeroSelectionDependentSensitivity(selectionCount, false);
 				SetStylesActivity(false, false, false);
 			}
 			else {
 				/* Multiple paths selected */
-				SetNonZeroSelectionDependentSensitivity(true);
+				SetNonZeroSelectionDependentSensitivity(selectionCount, true);
 				bool bold, italic, underline;
 				GetGlobalStyles(paths, out bold, out italic, out underline);
 				SetStylesActivity(bold, italic, underline);	
@@ -562,6 +614,32 @@ public class Menus {
     private void OnCommandManagerCommandActivated (object o, CommandActivatedArgs args) {
     	UpdateUndoRedoMessages();
     }
+    
+    	
+	private void OnTimingsInputFrameRateToggled (object o, EventArgs args) {
+		RadioMenuItem menuItem = o as RadioMenuItem;
+		if (menuItem.Active) {
+			float frameRate = FrameRateFromMenuItem((menuItem.Child as Label).Text);
+			Base.CommandManager.Execute(new ChangeInputFrameRateCommand(frameRate));
+		}
+	}
+	
+	private void OnTimingsVideoFrameRateToggled (object o, EventArgs args) {
+		RadioMenuItem menuItem = o as RadioMenuItem;
+		if (menuItem.Active) {
+			float frameRate = FrameRateFromMenuItem((menuItem.Child as Label).Text);
+			Base.CommandManager.Execute(new ChangeVideoFrameRateCommand(frameRate));
+		}
+	}
+
+	private void SetFrameRateMenuHandlers (Menu menu, bool enable, EventHandler handler) {
+		foreach (RadioMenuItem menuItem in menu.Children) {
+			if (enable)
+				menuItem.Toggled += handler;
+			else 
+				menuItem.Toggled -= handler;
+		}
+	}
 
 }
 
