@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2007-2010 Pedro Castro
+ * Copyright (C) 2007-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,7 +103,7 @@ public class SubtitleOverlay {
 	/* Event members */		
 
 	private void OnBaseInitFinished () {
-		Base.Ui.Video.Tracker.SubtitleChanged += OnCurrentSubtitleChanged;		
+		Base.Ui.Video.Tracker.CurrentSubtitleChanged += OnCurrentSubtitleChanged;		
 	}
 
 	private void OnCurrentSubtitleChanged (int indexSubtitle) {
