@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2010 Pedro Castro
+ * Copyright (C) 2006-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,9 +73,9 @@ public class SubtitleView {
 	
 	public void SetAutoSelectSubtitles (bool active) {
 		if (active)
-			Base.Ui.Video.Tracker.SubtitleChanged += OnCurrentSubtitleChanged;
+			Base.Ui.Video.Tracker.CurrentSubtitleChanged += OnCurrentSubtitleChanged;
 		else
-			Base.Ui.Video.Tracker.SubtitleChanged -= OnCurrentSubtitleChanged;
+			Base.Ui.Video.Tracker.CurrentSubtitleChanged -= OnCurrentSubtitleChanged;
 	}
 
 	
@@ -84,6 +84,11 @@ public class SubtitleView {
 	public void RedrawPath (TreePath path) {
 		subtitles.Model.EmitRowChanged(path, TreeIter.Zero);
 	}
+	
+	public void RedrawPaths (TreePath[] paths) {
+		foreach (TreePath path in paths)
+			RedrawPath(path);
+	}
 
 	/// <summary>Refreshes the view.</summary>
 	/// <remarks>This is currently limited to a <see cref="TreeView.QueueDraw()" />.</remarks>
@@ -133,6 +138,20 @@ public class SubtitleView {
 		return true;
 	}
 	
+	/// <summary>Inserts a new subtitle at the specified <see cref="TreePath" />, with the specified start time.</summary>
+	/// <param name="path">The path at which the new subtitle will be inserted.</param>
+	/// <param name="start">The time at which the new subtitle should start.</para>
+	/// <returns>Whether insertion was successful.</returns>
+	public bool InsertNewAt (TreePath path, TimeSpan start) {  //TODO merge nicely with existing subtitles (subtract times accordingly)
+		int index = Util.PathToInt(path);
+		if (!(subtitles.Collection.Contains(index) || (index == subtitles.Count)))
+			return false;
+
+		subtitles.AddNewAt(index, start);
+		selection.Select(path, true, true);
+		return true;
+	}
+	
 	/// <summary>Inserts a subtitle in the specified path.</summary>
 	public void Insert (Subtitle subtitle, TreePath path) {
 		int index = Util.PathToInt(path);
@@ -143,7 +162,7 @@ public class SubtitleView {
 	/// <summary>Inserts a collection of subtitles in the specified paths.</summary>
 	/// <param name="subtitles">The subtitles to insert.</param>
 	/// <param name="paths">The paths corresponding to each of the subtitles. There must be the same number of paths as there are for subtitles.</param>
-	/// <param name="focus">The tree that should be given the focus.</param>
+	/// <param name="focus">The path that should be given the focus.</param>
 	public void Insert (Subtitle[] subtitles, TreePath[] paths, TreePath focus) {
 		for (int index = 0 ; index < subtitles.Length ; index++) {
 			Subtitle subtitle = subtitles[index];
@@ -154,6 +173,16 @@ public class SubtitleView {
 		selection.Select(paths, focus, true);
 	}
 	
+	public void Insert (Subtitle[] subtitles, TreePath firstPath, TreePath focus) {
+		for (int index = 0, pathIndex = Util.PathToInt(firstPath) ; index < subtitles.Length  ; index++, pathIndex++) {
+			Subtitle subtitle = subtitles[index];
+			this.subtitles.Add(subtitle, pathIndex);		
+		}
+		TreePath lastPath = Util.IntToPath(Util.PathToInt(firstPath) + subtitles.Length - 1);
+		TreePath[] pathRange = new TreePath[]{firstPath, lastPath};
+		selection.SelectRange(pathRange, focus, true);
+	}
+	
 	/// <summary>Removes the subtitle at the specified path and selects the next or previous subtitle afterwards.</summary>
 	/// <param name="path">The path to remove.</param>
 	/// <param name="selectNext">Whether to select the next path after deletion, if possible.
@@ -226,20 +255,20 @@ public class SubtitleView {
     	
     	/* Start, end and duration columns */
     	int timeWidth = Util.ColumnWidth(tree, "00:00:00.000");
-    	startCol = Util.CreateTreeViewColumn(Catalog.GetString("From"), timeWidth, new CellRendererText(), RenderStartCell);
-    	endCol = Util.CreateTreeViewColumn(Catalog.GetString("To"), timeWidth, new CellRendererText(), RenderEndCell);
-    	durationCol = Util.CreateTreeViewColumn(Catalog.GetString("During"), timeWidth, new CellRendererText(), RenderDurationCell);
+    	startCol = Util.CreateTreeViewColumn(Catalog.GetString("Start"), timeWidth, new CellRendererText(), RenderStartCell);
+    	endCol = Util.CreateTreeViewColumn(Catalog.GetString("End"), timeWidth, new CellRendererText(), RenderEndCell);
+    	durationCol = Util.CreateTreeViewColumn(Catalog.GetString("Duration"), timeWidth, new CellRendererText(), RenderDurationCell);
     	
     	/* Text column */
     	int textWidth = Util.ColumnWidth(tree, "0123456789012345678901234567890123456789");
     	CellRendererText textCellRenderer = new CellRendererText();
     	textCellRenderer.Alignment = Pango.Alignment.Center;
-    	textCol = Util.CreateTreeViewColumn(Catalog.GetString("Text"), textWidth, textCellRenderer, RenderTextCell);
+    	textCol = Util.CreateTreeViewColumn(Catalog.GetString("Text"), textWidth, textCellRenderer, RenderSubtitleTextCell);
     	
     	/* Translation column */
     	CellRendererText translationCellRenderer = new CellRendererText();
     	translationCellRenderer.Alignment = Pango.Alignment.Center;
-    	translationCol = Util.CreateTreeViewColumn(Catalog.GetString("Translation"), textWidth, translationCellRenderer, RenderTranslationCell);
+    	translationCol = Util.CreateTreeViewColumn(Catalog.GetString("Translation"), textWidth, translationCellRenderer, RenderTranslationTextCell);
     	SetTranslationVisible(false);
 
     	tree.AppendColumn(numberCol);
@@ -300,36 +329,57 @@ public class SubtitleView {
 			renderer.Text = Util.TimeSpanToText(subtitles[iter].Times.Duration);
 	}
 	
-	private void RenderTextCell (TreeViewColumn column, CellRenderer cell, TreeModel treeModel, TreeIter iter) {
+	private void RenderSubtitleTextCell (TreeViewColumn column, CellRenderer cell, TreeModel treeModel, TreeIter iter) {
 		Subtitle subtitle = subtitles[iter];
-		CellRendererText renderer = cell as CellRendererText;		
-		renderer.Text = subtitle.Text.GetReplaceEmptyLines(" "); //Replace empty lines with a space so Pango doesn't complain
-		SetRendererStyle(renderer, subtitle);
+		RenderTextCell(cell as CellRendererText, iter, subtitle.Text, subtitle.Style);
 	}
 	
-	private void RenderTranslationCell (TreeViewColumn column, CellRenderer cell, TreeModel treeModel, TreeIter iter) {
+	private void RenderTranslationTextCell (TreeViewColumn column, CellRenderer cell, TreeModel treeModel, TreeIter iter) {
 		Subtitle subtitle = subtitles[iter];
-		CellRendererText renderer = cell as CellRendererText;		
-		renderer.Text = subtitle.Translation.GetReplaceEmptyLines(" "); //Replace empty lines with a space so Pango doesn't complain
-		SetRendererStyle(renderer, subtitle);		
+		RenderTextCell(cell as CellRendererText, iter, subtitle.Translation, subtitle.Style);
 	}
-	
-	private void SetRendererStyle (CellRendererText renderer, Subtitle subtitle) {
-		if (subtitle.Style.Italic)
-			renderer.Style = Pango.Style.Italic;
-		else
-			renderer.Style = Pango.Style.Normal;
-			
-		if (subtitle.Style.Bold)
-			renderer.Weight = (int)Pango.Weight.Bold;
-		else
-			renderer.Weight = (int)Pango.Weight.Normal;
 
-		if (subtitle.Style.Underline)
-			renderer.Underline = Pango.Underline.Single;
-		else
-			renderer.Underline = Pango.Underline.None;
+	private void RenderTextCell (CellRendererText renderer, TreeIter iter, SubtitleText subtitleText, SubLib.Core.Domain.Style subtitleStyle) {
+		
+		/* If there's no text, return empty text without line count */
+		if (subtitleText.IsEmpty) {
+			renderer.Text = String.Empty;
+			return;
+		}
+		
+		string textMarkup = String.Empty;
+		string stylePrefix = String.Empty;
+		string styleSuffix = String.Empty;
+		GetStyleMarkup(subtitleStyle, ref stylePrefix, ref styleSuffix);
+		
+		bool first = true;
+		bool viewLineLengths = Base.Config.PrefsViewLineLengths;
+		foreach (string line in subtitleText) {
+			textMarkup += (first ? String.Empty : "\n") + stylePrefix + GLib.Markup.EscapeText(line) + styleSuffix + (viewLineLengths ? " <span size=\"small\"><sup>(" + line.Length + ")</sup></span>" : String.Empty);
+			if (first)
+				first = false;
+		}
+			
+		renderer.Markup = textMarkup;
 	}
+
+	private void GetStyleMarkup (SubLib.Core.Domain.Style subtitleStyle, ref string prefix, ref string suffix) {
+		if (subtitleStyle.Italic) {
+			prefix += "<i>";
+			suffix = "</i>" + suffix;
+		}
+			
+		if (subtitleStyle.Bold) {
+			prefix += "<b>";
+			suffix = "</b>" + suffix;
+		}
+		
+		if (subtitleStyle.Underline) {
+			prefix += "<u>";
+			suffix = "</u>" + suffix;
+		}
+	}
+	
 	
 	/* Event members */
 	
@@ -339,12 +389,13 @@ public class SubtitleView {
 		Base.TranslationLoaded += OnBaseTranslationLoaded;
 		Base.TranslationUnloaded += OnBaseTranslationUnloaded;
 		Base.TimingModeChanged += OnBaseTimingModeChanged;
+		
+		(Base.Ui.Menus.GetMenuItem(WidgetNames.ViewLineLengths) as CheckMenuItem).Toggled += OnViewLineLengthsToggled;
 	}
 	
 	private void OnBaseDocumentLoaded (Document document) {
    		tree.Sensitive = true;
     	Load(document.Subtitles);
-		selection.SelectFirst();
     }
     
     private void OnBaseDocumentUnloaded (Document document) {
@@ -394,6 +445,10 @@ public class SubtitleView {
     private void SetEmptyModel () {
     	tree.Model = new ListStore(typeof(Subtitle));
     }
+    
+    private void OnViewLineLengthsToggled (object o, EventArgs args) {
+    	Refresh();
+	}
 		
 }
 
