@@ -1,6 +1,6 @@
 /*
  * This file is part of SubLib.
- * Copyright (C) 2005-2008 Pedro Castro
+ * Copyright (C) 2005-2008,2011 Pedro Castro
  *
  * SubLib is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,10 +18,12 @@
  */
 
 using SubLib.Core.Domain;
+using SubLib.Exceptions;
 using SubLib.IO.SubtitleFormats;
 using SubLib.IO.Input;
 using SubLib.IO.Output;
 using System;
+using System.IO;
 using System.Text;
 using System.Text.RegularExpressions;
 
@@ -37,9 +39,14 @@ public class SubtitleFactory {
 	
 	private Encoding encoding = null; //The encoding to be used to open a file 
 	private Encoding fallbackEncoding = Encoding.GetEncoding(1252); //The encoding to fall back to when no encoding is detected
+	private float inputFrameRate = 25; //The frame rate to be used to open a frame-based file
+	private int maxFileSize = 1000000; //The size limit for a subtitle file, in bytes
 	
 	private SubtitleType subtitleType = SubtitleType.Unknown;
 	
+	
+	/* Public properties */
+	
 	/// <summary>The incomplete subtitles that were found when opening a file.</summary>
 	/// <remarks>This is only used when <see cref="IncludeIncompleteSubtitles" /> is set.</remarks>
 	public IncompleteSubtitleCollection IncompleteSubtitles {
@@ -89,6 +96,22 @@ public class SubtitleFactory {
 		set { subtitleType = value; }
 	}
 	
+	/// <summary>The frame rate of the subtitle being opened, for frame-based files.</summary>
+	public float InputFrameRate {
+		get { return inputFrameRate; }
+		set { inputFrameRate = value; }
+	}
+	
+	/// <summary>The file size limit for subtitle files, in bytes.</summary>
+	/// <remarks>Defaults to 1,000,000 bytes (1MB). Setting the value to -1 disables validation.</remarks>
+	public int MaxFileSize {
+		get { return maxFileSize; }
+		set { maxFileSize = value; }
+	}
+	
+	
+	/* Public methods */
+	
 	/// <summary>Creates new empty <see cref="Subtitles" />.</summary>
 	/// <returns>The newly created subtitles.</returns>
 	public Subtitles New () {
@@ -105,7 +128,14 @@ public class SubtitleFactory {
 	public Subtitles Open (string path){
 		SubtitleFormat format = null;
 		string text = String.Empty;
-		Encoding fileEncoding = null;	
+		Encoding fileEncoding = null;
+		
+		if (maxFileSize != -1) {
+			FileInfo info = new FileInfo(path);
+			if (info.Length > maxFileSize) {
+				throw new FileTooLargeException(String.Format("The file size ({0:n} bytes) is larger than the maximum limit ({1:n} bytes).", info.Length, maxFileSize));
+			}
+		}
 		
 		SubtitleInput input = new SubtitleInput(fallbackEncoding, subtitleType);
 		if (encoding == null) {
@@ -119,7 +149,7 @@ public class SubtitleFactory {
 		if (IsTextEmpty(text))
 			return EmptySubtitles(path);
 		else
-			return ParsedSubtitles(path, fileEncoding, format, text);
+			return ParsedSubtitles(path, fileEncoding, format, inputFrameRate, text);
 	}
 	
 	/// <summary>Creates <see cref="Subtitles" /> by opening the plain text file at the specified path.</summary>
@@ -148,10 +178,10 @@ public class SubtitleFactory {
 		
 	/* Private members */
 		
-	private Subtitles ParsedSubtitles (string path, Encoding fileEncoding, SubtitleFormat format, string text) {
+	private Subtitles ParsedSubtitles (string path, Encoding fileEncoding, SubtitleFormat format, float inputFrameRate, string text) {
 		SubtitleCollection collection = null;
 		SubtitleParser subtitleParser = new SubtitleParser(includeIncompleteSubtitles);
-		ParsingProperties parsingProperties = subtitleParser.Parse(text, format, out collection, out incompleteSubtitles);
+		ParsingProperties parsingProperties = subtitleParser.Parse(text, format, inputFrameRate, out collection, out incompleteSubtitles);
 		
 		SubtitleProperties subtitleProperties = new SubtitleProperties(parsingProperties);
 		collection.SetPropertiesForAll(subtitleProperties);
@@ -159,14 +189,13 @@ public class SubtitleFactory {
 		Subtitles subtitles = new Subtitles(collection, subtitleProperties);
 		CompleteTimingsAfterParsing(subtitles, parsingProperties);
 		
-		fileProperties = new FileProperties(path, fileEncoding, format.Type , parsingProperties.TimingMode);
+		fileProperties = new FileProperties(path, fileEncoding, format.Type, parsingProperties.TimingMode);
 
-		VerboseConsole.WriteLine("[*] opened " + path + " with encoding " + fileEncoding + " and format " + format.Name);
+		VerboseConsole.WriteLine("[*] Opened \"" + path + "\" with encoding \"" + fileEncoding + "\", format \"" + format.Name + "\", timing mode \"" + parsingProperties.TimingMode + "\" and frame rate \"" + subtitleProperties.CurrentFrameRate + "\" (input frame rate was \"" + inputFrameRate + "\")");
 		return subtitles;
 	}
 	
-	private Subtitles ParsedSubtitlesPlain (string path, Encoding fileEncoding, string text, bool withCharacterNames,
-		                                        TimingMode timingMode, string lineSeparator) {
+	private Subtitles ParsedSubtitlesPlain (string path, Encoding fileEncoding, string text, bool withCharacterNames, TimingMode timingMode, string lineSeparator) {
 		SubtitleCollection collection = null;
 		PlainTextParser plainParser = new PlainTextParser(withCharacterNames, lineSeparator);
 		ParsingProperties parsingProperties = plainParser.Parse(text, timingMode, fileEncoding, out collection);
@@ -179,7 +208,7 @@ public class SubtitleFactory {
 		
 		fileProperties = new FileProperties(path, fileEncoding, parsingProperties.TimingMode);
 		
-		VerboseConsole.WriteLine("[*] opened " + path + " with encoding " + fileEncoding);
+		VerboseConsole.WriteLine("[*] Opened " + path + " with encoding " + fileEncoding);
 		return subtitles;
 	}
 		
